RAW = {
    'status': {
        'hrDeviceStatus': 2,
        'status1': '  Sleeping...   ',
        'status2': '                ',
        'status3': '',
        'status4': ''
    },
    'identity': {
        'model_name': 'M2070 Series',
        'host_name': 'SEC811119110648',
        'location': '',
        'serial_num': 'ZFAYB8KGGGG1GZP',
        'ip_addr': '192.168.0.0',
        'ipv6_link_addr': '',
        'mac_addr': '84:25:00:00:06:48',
        'admin_email': '',
        'admin_name': '',
        'admin_phone': '',
        'customer_support': ''
    },
    'toner_black': {
        'opt': 1,
        'remaining': 58,
        'cnt': 229,
        'newError': ''
    },
    'toner_cyan': {
        'opt': 0,
        'remaining': 0,
        'cnt': 0,
        'newError': ''
    },
    'toner_magenta': {
        'opt': 0,
        'remaining': 0,
        'cnt': 0,
        'newError': ''
    },
    'toner_yellow': {
        'opt': 0,
        'remaining': 0,
        'cnt': 0,
        'newError': ''
    },
    'drum_black': {
        'opt': 0,
        'remaining': 0,
        'newError': ''
    },
    'drum_cyan': {
        'opt': 0,
        'remaining': 100,
        'newError': ''
    },
    'drum_magenta': {
        'opt': 0,
        'remaining': 100,
        'newError': ''
    },
    'drum_yellow': {
        'opt': 0,
        'remaining': 100,
        'newError': ''
    },
    'tray1': {
        'opt': 1,
        'paper_size1': 4,
        'paper_size2': 0,
        'paper_type1': 2,
        'paper_type2': 0,
        'capa': 150,
        'newError': ''
    },
    'tray2': {
        'opt': 0,
        'paper_size1': 0,
        'paper_size2': 0,
        'paper_type1': 2,
        'paper_type2': 0,
        'capa': 0,
        'newError': ''
    },
    'tray3': {
        'opt': 0,
        'paper_size1': 0,
        'paper_size2': 0,
        'paper_type1': 2,
        'paper_type2': 0,
        'capa': 0,
        'newError': ''
    },
    'tray4': {
        'opt': 0,
        'paper_size1': 0,
        'paper_size2': 0,
        'paper_type1': 2,
        'paper_type2': 0,
        'capa': 0,
        'newError': ''
    },
    'tray5': {
        'opt': 0,
        'paper_size1': 0,
        'paper_size2': 0,
        'paper_type1': 0,
        'paper_type2': 0,
        'capa': 0,
        'newError': '0'
    },
    'mp': {
        'opt': 0,
        'paper_size1': 0,
        'paper_size2': 0,
        'paper_type1': 2,
        'paper_type2': 0,
        'capa': 0,
        'newError': ''
    },
    'manual': {
        'opt': 0,
        'paper_size1': 0,
        'paper_size2': 0,
        'paper_type1': 2,
        'paper_type2': 0,
        'capa': 0,
        'newError': ''
    },
    'GXI_INTRAY_MANUALFEEDING_TRAY_SUPPORT': 0,
    'GXI_INSTALL_OPTION_MULTIBIN': 0,
    'multibin': [['Bin', 100, 0]],
    'outputTray': [[1, 100, '']],
    'capability': {
        'hdd': {
            'opt': 2,
            'capa': 0
        },
        'ram': {
            'opt': 131072,
            'capa': 131072
        },
        'scanner': {
            'opt': 0,
            'capa': 0
        }
    },
    'options': {
        'wlan': 1
    },
    'GXI_ACTIVE_ALERT_TOTAL': 0,
    'GXI_ADMIN_WUI_HAS_DEFAULT_PASS': 1,
    'GXI_SUPPORT_COLOR': 2,
    'GXI_SYS_LUI_SUPPORT': 1,
    'GXI_A3_SUPPORT': 0,
    'GXI_TRAY2_MANDATORY_SUPPORT': 0,
    'GXI_SWS_ADMIN_USE_AAA': 0,
    'GXI_TONER_BLACK_VALID': 1,
    'GXI_TONER_CYAN_VALID': 1,
    'GXI_TONER_MAGENTA_VALID': 1,
    'GXI_TONER_YELLOW_VALID': 1,
    'GXI_IMAGING_BLACK_VALID': 1,
    'GXI_IMAGING_CYAN_VALID': 1,
    'GXI_IMAGING_MAGENTA_VALID': 1,
    'GXI_IMAGING_YELLOW_VALID': 1,
    'GXI_SUPPORT_PAPER_SETTING': 1
}
